[![PyPi Version](https://img.shields.io/pypi/v/vacefron.py.svg)](https://pypi.python.org/pypi/vacefron.py/)
[![Downloads](https://pepy.tech/badge/vacefron-py)](https://pepy.tech/project/vacefron-py)
[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/tterb/Atomic-Design-UI/blob/master/LICENSE.md)

# VACEfron.py

A Wrapper for [vacefron.nl/api](https://vacefron.nl/api/) written in Python.

## Requirements

- Python 3.6 or above
- aiohttp (python3 -m pip install -U aiohttp)

## Installation

Install the package by doing one of the following commands:

**Using pip (recommended)**:

- `pip install vacefron.py -U`
- `python -m pip install vacefron.py -U`

## Documentation

See the full and detailed [docs here](docs.md)

## Links

[API](https://vacefron.nl/api/) | [Changelogs](https://github.com/Soheab/vacefron.py/blob/master/changelog.md)
| [Examples](https://github.com/Soheab/vacefron.py/blob/master/docs.md#examples)

## Made by

This wrapper is made by **Soheab#6240**. DM me on Discord or join my server [here](https://discord.gg/yCzcfju) for
anything related to this wrapper.

You can join VAC Efron's server [here](https://discord.gg/xJ2HRxZ) to suggest or report anything on the API.

## Other Wrappers

- **Csharp:** [GitHub](https://github.com/VACEfron/VACEfron.NET) | [Nuget](https://www.nuget.org/packages/VACEfron.NET)
- **Javascript:** [GitHub](https://github.com/Sidemen19/VACEfron.js) | [Npm](https://npmjs.com/package/vacefron)
- **Java:** [GitHub](https://github.com/thunderstorm010/VACEfron4J)
